@@ -92,13 +92,22 @@ class TasksWriter(WriterBase):
                             else:
                                 mdFile.new_paragraph('* No description available for this task - here is the definition:')
                                 mdFile.new_line("```")
-                                mdFile.new_paragraph(yaml.safe_dump(task,  default_flow_style=False))
+                                mdFile.new_paragraph(yaml.safe_dump(task,  default_flow_style=False, allow_unicode=True))
                                 mdFile.new_line("```")
                             
                             if 'tags' in task.keys():
                                 mdFile.write('  \n')
-                                mdFile.write('Tags: ', bold_italics_code='b', color='green')
-                                mdFile.write(task["tags"])
+                                mdFile.write('Tags: ', color='green')
+                                if isinstance(task["tags"], list):
+                                    taglist = ""
+                                    for tag in task["tags"]:
+                                        if taglist == "":
+                                            taglist = tag
+                                        else:
+                                            taglist = taglist+","+tag
+                                    mdFile.write(taglist)
+                                else:
+                                    mdFile.write(task["tags"])
                         except Exception:
                             print(task)
                             pass
